package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````L"4```````!``````````$"Q````
M`````````$``.``-`$``'``;``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````-@9````````V!D`````````
M$`````````$````%`````"``````````(``````````@````````Y3T`````
M``#E/0`````````0`````````0````0`````8`````````!@`````````&``
M``````!02````````%!(`````````!`````````!````!@```."K````````
MX+L```````#@NP```````$`$````````N`0`````````$`````````(````&
M````\*L```````#PNP```````/"[``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````@````````
M`"``````````"``````````$````!````%@#````````6`,```````!8`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````(``````````@``````````@`````````4.5T9`0`
M```@H0```````""A````````(*$```````#L`````````.P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````X*L```````#@NP```````."[````
M````(`0````````@!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````$`````4```!'3E4``H``P`0````!````````
M``0````4`````P```$=.50`>2FB/F(_H=)!L@UPOXY$>$H]3AP0````0````
M`0```$=.50```````P````(``````````````!$````_````!`````@````@
M'!``!4`$AB@"0`20A@"$@@D`($D@!`BX@A%!N@`""@`````_````0@```$4`
M``!&````30```$X```!0`````````%0```!5````5@```%D```!;````70``
M````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP$+ZUX?"Y3\LNN.2?/NA;&!K"4/69J_,9L6YG$`X\HL<Q(D%D$)%U>R)
M!W#3,V+;[16,)<P,.I<+5J2;EJ?=HVM^J9R;T67.;>"G`@IK&IY0"HH05Z/@
M^TD`````````````````````````````````````W````!(`````````````
M````````````@P```!(`````````````````````````)`(``!(`````````
M````````````````50$``!(`````````````````````````!P(``!(`````
M````````````````````S@$``!(`````````````````````````\@```!(`
M````````````````````````'0```"``````````````````````````EP(`
M`!(`````````````````````````S0(``!(`````````````````````````
MC0$``!(`````````````````````````^`$``!(`````````````````````
M````;`$``!(`````````````````````````(P$``!(`````````````````
M````````$P$``!(`````````````````````````Z@$``!(`````````````
M````````````'@(``!(`````````````````````````!0$``!(`````````
M````````````````F0$``!(`````````````````````````>0,``!(`````
M`````````````````````0```"``````````````````````````<P$``!(`
M````````````````````````X0```!(`````````````````````````*@(`
M`!(`````````````````````````+````"``````````````````````````
M;P(``!(`````````````````````````=@(``!(`````````````````````
M````1@```!(`````````````````````````10$``!(`````````````````
M````````8P```!(`````````````````````````P````!(`````````````
M````````````=````!(`````````````````````````9@(``!(`````````
M````````````````XP$``!(`````````````````````````%P(``!(`````
M````````````````````I````!(`````````````````````````G`(``!(`
M````````````````````````H`$``!(`````````````````````````D@$`
M`!(`````````````````````````-P$``!(`````````````````````````
MA@(``!(`````````````````````````,0(``!(`````````````````````
M````Y@```!(`````````````````````````I0(``!(`````````````````
M````````W`$``!(`````````````````````````\0$``!(`````````````
M````````````;@(``!(```````````````````````````(``!(`````````
M````````````````J`$``!(`````````````````````````CP```!(`````
M````````````````````8`$``!(`````````````````````````?@(``!(`
M````````````````````````#@(``!(`````````````````````````2@(`
M`!(`````````````````````````M@(``!(`````````````````````````
M.`(``!(`````````````````````````+`$``!(`````````````````````
M````5````!(`````````````````````````O`$``!(`````````````````
M````````7P(``!(`````````````````````````0`(``!(`````````````
M````````````O0(``!(`````````````````````````@@,``!(`#P``0@``
M`````!0!````````UP,``!(`#P"0-P```````.`'````````R0$``!(`#P"P
M(P```````/H!````````^0(``!(`#P#P+0````````4`````````%P,``!(`
M#P!P/P```````(T"````````_0,``!(`#P``+@````````("````````O0,`
M`!``&0`@P```````````````````"@,``!(`#P`0,````````"(`````````
M+0,``!(`#P#@-0```````'0`````````C@,``!$`$0``8`````````0`````
M````J@,``!(`#P#@60```````)\!````````M0,``!(`#P``+0```````#``
M````````T@,``!``&0"8P```````````````````ZP,``!(`#P"`-@``````
M``L!````````G0,``!``&```P```````````````````40,``!(`#P!`,```
M`````#$!````````PP(``!$`&0!`P`````````@`````````6`(``!$`&0!@
MP`````````@`````````Q`(``"$`&0!`P`````````@`````````Y`,``!``
M&``@P```````````````````"@0``!$`&``8P`````````@`````````HP,`
M`!(`#P"P)0```````"(`````````R0,``!(`#P"060```````$4`````````
MGP,``"``&```P```````````````````T0```!$`&0`@P`````````0`````
M````Q0(``"$`&0!`P`````````@`````````9P,``!(`#P!@-@```````!T`
M````````?@$``"(`````````````````````````.P,``!(`#P`P+0``````
M`+D`````````70,``!(`#P"`6P```````$L"````````LP```!$`&0!PP```
M``````$`````````%`0``!(`#P"`,0```````%P$`````````%])5$U?9&5R
M96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES
M=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U
M;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L
M7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T
M`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!P97)L7V%L;&]C`%]?8WAA7V9I;F%L:7IE`')E860`<W1R8VAR`&=E='!I
M9`!M96UM;W9E`'!T:')E861?9V5T<W!E8VEF:6,`7U]L:6)C7W-T87)T7VUA
M:6X`7U]F<')I;G1F7V-H:P!S=')C;7``;W!E;C8T`'5N;&EN:P!S=')T;VL`
M<W1R;F-M<`!G971U:60`;65M8VAR`&-L;W-E9&ER`'-T<G-T<@!R;61I<@!C
M;&]S90!S=')L96X`<W1R9'5P`')E86QL;V,`<F5A9&1I<C8T`%]?<W!R:6YT
M9E]C:&L`<W1D97)R`&UE;6-P>0!S=')R8VAR`&QS=&%T-C0`;W!E;F1I<@!L
M<V5E:S8T`%]?97)R;F]?;&]C871I;VX`97AI=`!R96%D;&EN:P!?7W-T86-K
M7V-H:U]F86EL`&%C8V5S<P!M:V1I<@!?7V5N=FER;VX`7U]R96=I<W1E<E]A
M=&9O<FL`;&EB<&5R;"YS;RXU+C,T`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E
M>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N
M=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA
M7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN
M:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D
M871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`
M<&%R7VEN:71?96YV`$=,24)#7S(N,30`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`
M1TQ)0D-?,BXS,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C,N-`!'3$E"0U\R+C(N
M-0````$``0`"``$``@`#``$``0`"``0``@`"``(``0`!``(``@`!``(``@`!
M``$``@`"``$`!0`"``$``0`!``$``0`"``(``@`!``(``@`"``$``@`"``$`
M!@`"``(`!0`"``<``0`!``(``@`#``(``@`!``$`!P`(``(``@`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``(``@`"``$``0`!``$``0`!``(`
M`0`"``$``0`!``$````!``<`[P(``!``````````E)&6!@``"``A!```$```
M`+21E@8```<`+`0``!`````4:6D-```&`#<$```0````LY&6!@``!0!!!```
M$````'(9:0D```0`3`0``!````!T&6D)```#`%@$```0````=1II"0```@!D
M!````````."[````````"`````````"0)@```````.B[````````"```````
M``!0)@````````C`````````"``````````(P````````!C`````````"```
M``````#88@```````,"_````````!@````<``````````````,B_````````
M!@````@``````````````-"_````````!@```!4``````````````-B_````
M````!@```!D``````````````."_````````!@```%H``````````````.B_
M````````!@```!T``````````````/"_````````!@```!X`````````````
M`/B_````````!@```#L``````````````"#`````````!0```%<`````````
M`````$#`````````!0```$\``````````````&#`````````!0```%``````
M`````````'#`````````!0```%T```````````````B^````````!P````$`
M`````````````!"^````````!P````(``````````````!B^````````!P``
M``,``````````````""^````````!P````0``````````````"B^````````
M!P````4``````````````#"^````````!P````8``````````````#B^````
M````!P````D``````````````$"^````````!P````H``````````````$B^
M````````!P````L``````````````%"^````````!P````P`````````````
M`%B^````````!P````T``````````````&"^````````!P````X`````````
M`````&B^````````!P````\``````````````'"^````````!P```!``````
M`````````'B^````````!P```!$``````````````("^````````!P```!(`
M`````````````(B^````````!P```!,``````````````)"^````````!P``
M`!0``````````````)B^````````!P```!8``````````````*"^````````
M!P```!<``````````````*B^````````!P```!@``````````````+"^````
M````!P```!H``````````````+B^````````!P```!L``````````````,"^
M````````!P```!P``````````````,B^````````!P```!\`````````````
M`-"^````````!P```"```````````````-B^````````!P```"$`````````
M`````."^````````!P```"(``````````````.B^````````!P```",`````
M`````````/"^````````!P```"0``````````````/B^````````!P```"4`
M``````````````"_````````!P```"8```````````````B_````````!P``
M`"<``````````````!"_````````!P```"@``````````````!B_````````
M!P```"D``````````````""_````````!P```"H``````````````"B_````
M````!P```"L``````````````#"_````````!P```"P``````````````#B_
M````````!P```"T``````````````$"_````````!P```"X`````````````
M`$B_````````!P```"\``````````````%"_````````!P```#``````````
M`````%B_````````!P```#$``````````````&"_````````!P```#(`````
M`````````&B_````````!P```#,``````````````'"_````````!P```#0`
M`````````````'B_````````!P```#4``````````````("_````````!P``
M`#8``````````````(B_````````!P```#<``````````````)"_````````
M!P```#@``````````````)B_````````!P```#D``````````````*"_````
M````!P```#H``````````````*B_````````!P```#P``````````````+"_
M````````!P```#T``````````````+B_````````!P```#X`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%O9\``$B%P'0"_]!(@\0(PP```````````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@_____R7*G0``:`$```#IT/____\EPIT``&@"
M````Z<#_____);J=``!H`P```.FP_____R6RG0``:`0```#IH/____\EJIT`
M`&@%````Z9#_____):*=``!H!@```.F`_____R6:G0``:`<```#I</____\E
MDIT``&@(````Z6#_____)8J=``!H"0```.E0_____R6"G0``:`H```#I0/__
M__\E>IT``&@+````Z3#_____)7*=``!H#````.D@_____R5JG0``:`T```#I
M$/____\E8IT``&@.````Z0#_____)5J=``!H#P```.GP_O___R52G0``:!``
M``#IX/[___\E2IT``&@1````Z=#^____)4*=``!H$@```.G`_O___R4ZG0``
M:!,```#IL/[___\E,IT``&@4````Z:#^____)2J=``!H%0```.F0_O___R4B
MG0``:!8```#I@/[___\E&IT``&@7````Z7#^____)1*=``!H&````.E@_O__
M_R4*G0``:!D```#I4/[___\E`IT``&@:````Z4#^____)?J<``!H&P```.DP
M_O___R7RG```:!P```#I(/[___\EZIP``&@=````Z1#^____)>*<``!H'@``
M`.D`_O___R7:G```:!\```#I\/W___\ETIP``&@@````Z>#]____)<J<``!H
M(0```.G0_?___R7"G```:"(```#IP/W___\ENIP``&@C````Z;#]____);*<
M``!H)````.F@_?___R6JG```:"4```#ID/W___\EHIP``&@F````Z8#]____
M)9J<``!H)P```.EP_?___R62G```:"@```#I8/W___\EBIP``&@I````Z5#]
M____)8*<``!H*@```.E`_?___R5ZG```:"L```#I,/W___\E<IP``&@L````
MZ2#]____)6J<``!H+0```.D0_?___R5BG```:"X```#I`/W___\E6IP``&@O
M````Z?#\____)5*<``!H,````.G@_/___R5*G```:#$```#IT/S___\E0IP`
M`&@R````Z<#\____)3J<``!H,P```.FP_/___R4RG```:#0```#IH/S___\E
M*IP``&@U````Z9#\____)2*<``!H-@```.F`_/___R4ZG```9I``````````
M`%532(/L.(E\)!Q(C7PD'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H````
M2(E$)"@QP.AX____2(LUT9L``$B+/?J;``!(B?+HTCD``(`]:YP```!U+^A$
M_?__2(D%?9P``$B)QTB%P`^$?`$``.B<_?__BSWVFP``Z*'^___&@-<)````
MBSWDFP``Z(_^__^+/=F;``"`B"H$```"Z'W^__^`B"H$```!BT0D'(UX!(U8
M`TAC_TC!YP/H@/[__TB+?"002(G!2(D%"9P``$B+!TB)`4B-!3<]``!(B4$(
M2(L%@9L``$B)01!(C04D/0``2(E!&(M$)!R#^`$/CMX```!(@\<(@\`#N@0`
M``"03(L'2&/R@\(!2(/'"$R)!/$YT'7K2)A(BSVRFP``B=I%,<!(QP3!````
M`$B--9X'``#H:?O__XG#A<!T44B+/8R;``!(C6PD).@R_?__,<!(B>Y(C3V)
M.P``Z($!``!(A<!T.DB+/66;``#H`/O__^AK_/__2(M$)"AD2"L$)2@```!U
M8$B#Q#B)V%M=PTB+/3N;``#HAOO__XG#ZY](BST;FP``2(7_=`?HD1P``.NS
M2(T]X#H``$B)[N@@`0``2(D%^9H``$B)QTB%P'25Z]FX!````.DZ____OP$`
M``#HZ_K__^C6_/__9@\?1```,>U)B=%>2(GB2(/D\%!413'`,<E(C3WE_?__
M_Q4GF@``]&8N#Q^$```````/'T``2(T].9H``$B-!3*:``!(.?AT%4B+!=:9
M``!(A<!T"?_@#Q^``````,,/'X``````2(T]"9H``$B--0*:``!(*?Y(B?!(
MP>X_2,'X`T@!QDC1_G042(L%G9D``$B%P'0(_^!F#Q]$``###Q^``````/,/
M'OJ`/1::````=2M52(,]>ID```!(B>5T#$B+/9:9``#H*?W__^AD____Q@7N
MF0```5W##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````05=!5D%505154TB#
M[`A(A?\/A+$```!,BS6"F0``387V#X2A````#[8'28G_28GUA,!T!#P]=5A%
M,>1)BQY(A=MT,TUCY$R)]0\?@`````!,B>),B?Y(B=_HPOG__X7`=0="@#PC
M/71'2(M="$B#Q0A(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M00^V1"0!28/$`83`=`0\/77N12G\ZY%F#Q]$``!,*?5*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$))@````Q
MP$B)YN@:^___A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*```'4>O@(```!(
MB=_H;_O__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@```!D2"L4)2@```!U"4B!
MQ*````!;P^B-^O__9F8N#Q^$``````!FD$%505154TB![*@```!D2(L$)2@`
M``!(B80DF````#'`2(7_=`B`/P!(B?MU*TB+A"28````9$@K!"4H````#X4C
M`0``2('$J````%M=05Q!7<-F#Q]$``#H,_G__TB)Q4B%P'3(2(GOZ!/[__](
MA<`/A+(```"`>!,N3(U@$W4008!\)`$`=-T/'X0``````(!X$RX/A*8```!(
MB=_HSOC__TR)YTF)Q>C#^/__08U\!0)(8__H%OC__TV)X4F)V+X!````28G%
M2(G',<!(Q\+_____2(T-*3<``.A`^O__3(GO2(GFZ)7X__],B>^#^/]T$(M$
M)!@E`/```#T`0```=%WH^/?__TR)[^A0^/__2(GOZ&CZ__](A<`/A57___\/
M'X``````2(GOZ.#Y__](B=_HV/?__^GP_O__#Q\`08!\)`$N#X5.____08!\
M)`(`#X0-____Z3W___\/'P#HF_[__^NAZ!3Y__\/'T``056Z_P\``$%454B)
M]5-(B?M(C3V"-@``2('L&!```&1(BP0E*````$B)A"0($```,<!)B>1,B>;H
M8_C__X7`?A*)P8/H`4ACT(`\%`!U287`=3V+/5>6``#H`OG__TB)ZDB)WDB)
MQ^A$]___2(N$)`@0``!D2"L$)2@```!U3TB!Q!@0``!;74%<05W##Q\`B<%F
M#Q]$``!,8^F^+P```$R)YTR)ZNA5]O__2(7`=*.+/?J5``#HI?C__TR)Z4R)
MXDB)WDB)Q^C$]___ZY[H/?C__V9F+@\?A```````9I!!5T%6055!5%5(B?53
M2(G[2(/L&&1(BP0E*````$B)1"0(,<`QP(`^/0^4P$@!Q4B)[^CI]O__2(UT
M)`1(B=])B<0QP.@'_/__2(7`#X0&`0``2(G'28G%Z,/V__],.>`/@](```!,
M8W0D!$G!Y@,/M@.$P`^$G@$``#P]#X26`0``2(G8#Q\`#[90`4B#P`&$TG0%
M@/H]=>](*=A(F$R++4N5``!*C7P@`NC1]?__30'U28E%`$B%P'162(L%+I4`
M`$B-2P%*BQ0P#[8#B`*$P'0B/#UU#>L<#Q^``````(3`=!$/M@%(@\(!2(/!
M`8@"/#UUZ\8"/3'`9@\?1```#[9,!0"(3`(!2(/``83)=>](BT0D"&1(*P0E
M*`````^%!P$``$B#Q!A;74%<05U!7D%?PP\?0``QP&8/'T0```^V5`4`08A4
M!0!(@\`!A-)U[NN]#Q]``$R+/9&4``!)@S\`#X2V````3(GX13'MD$B#P`A$
MB>I!@\4!2(,X`'7OC7(#2&/V2,'F`XL%EY0``(7`=5O'!8F4```!````2(GW
MZ-GT__](A<`/A&'___]-8_5,B?Y(B<=)P>8#3(GRZ`OV__](B04DE```2(G!
M08U%`42);"0$2)A(QP3!`````.F(_O__9@\?A```````3(G_Z/CV__](B07Q
MDP``2(G!2(7`#X0&____36/U2<'F`^N[#Q]``#'`Z7_^__^^$````$4Q[>E?
M____Z/_U__]F9BX/'X0```````\?0`!(@^P(BSV&DP``Z#'V__^+/7N3``#H
M)O;__TB+%3>3``!(C0T8=```2(TU6C,``$B)Q^B)]O__BSU3DP``Z/[U__],
MC07'-```13')2(T5C1(``$B)QTR)P4B--44S``!(@\0(Z;?T__\/'X``````
M2(/L"(L]%I,``.C!]?__2(L5TI(``$B#Q`A(C0VO<P``2(G'2(TU[C(``.D@
M]O__55-(@>PH(```9$B+!"4H````2(F$)!@@```QP$B)XTB-K"00$```Z-3S
M__^Z`1```$B)W[X!````08G`3(T-HC(``#'`2(T-SC(``.B?]?__N@`0``!(
MB>Y(B=_H?_3__X7`>%"->`%(B<-(8__H+?/__TB%P'0]2&/;2(GN2(G'2(G:
MZ+?U___&!!@`2(G!2(N$)!@@``!D2"L$)2@```!U#4B!Q"@@``!(B<A;7</H
MF_3__S')Z]</'X``````Z3O___]F9BX/'X0``````$%7059!54%428G\2(T]
M1C(``%532(GS2('LN!```&1(BP0E*````$B)A"2H$```,<!(C70D#.AE^/__
MOB\```!,B>=(B<7HY?/__TB%P'1`,<!,B>9(C3T%,@``Z._[__],B>!(BY0D
MJ!```&1(*Q0E*`````^%@@$``$B!Q+@0``!;74%<05U!7D%?PP\?`$B)WTR-
M+=0Q``!,C36Z,@``Z+KS__],B>Y(B<?H[_/__TB)PTB%P'27@#L`#X3D````
M9@\?1```2(7M=!-(B=Y(B>_HN//__X7`#X2G````2(G?Z(CR__](C50#_TF)
MQT@YTW(7ZR5F#Q^$``````#&`@!(@^H!2#G3=`6`.B]T[TB)W^A7\O__28G'
M3(GGZ$SR__])C40'`4@]_P\```^'&____TR-O"2@````3(GQ28G8,<!(@^P(
MN@`0``"^`0```$R)_T%43(T-$3$``.B\\___2(UT)"!,B?_H#_+__UI9A<!U
M$(M$)"@E`/```#T`@```=$E,B>XQ_^@/\___2(G#2(7`#X2S_O__@#L`#X4B
M____2(7M=`:`?0`N=!=!OP$```!(C1V8,```Z5G___\/'T0``(!]`0!TN>OA
MO@$```!,B?_H4_/__X7`=:9,B?Y(C3UV,```Z&#Z__],B?_H:/+__^EG_O__
MZ'[R__]F9BX/'X0```````\?`%.^+P```$B)^^BR\?__2(U0`4B%P$@/1=I(
MB=];Z2[R__]F9BX/'X0```````\?`%532('L&!```&1(BP0E*````$B)A"0(
M$```,<!(A?\/A,L```"`/P!(B?L/A+\```#H^O#__TB-4`%(@?H`$```#X?A
M````2(GE2(GO@_H(<@Z)T4B)WL'I`_-(I4B)\S')]L($=`F+"XD/N00```#V
MP@)T#D0/MP0+9D2)!`](@\$"@^(!=`</MA0+B!0/2(U$!?](.<5R$^L6#Q]$
M``#&``!(@^@!2#GH=`6`."]T[[XO````2(GOZ-+P__](A<!T+4@YQ7)82(GO
MZ%#Q__](BY0D"!```&1(*Q0E*````'5)2('$&!```%M=PP\?`$B+A"0($```
M9$@K!"4H````=2E(@<08$```2(T]!2\``%M=Z0CQ__\/'X0``````,8``.NC
M#Q\`,<#KI.@/\?__9F8N#Q^$```````/'T``05=!5D%505152(TMXBX``%-(
M@^P89$B+!"4H````2(E$)`@QP$B-7"0$9@\?1```,<!(B=Y(B>_HX_3__TB%
MP'0V2&-4)`1(BP5RC@``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```2(TM?"X``)`QP$B)WDB)[^B3]/__2(7`=#9(8U0D!$B+
M!2*.``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$
M``!(C2TT+@``D#'`2(G>2(GOZ$/T__](A<!T-DAC5"0$2(L%THT``$B-!-!(
MBU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-+>TM``"0
M,<!(B=Y(B>_H\_/__TB%P'0V2&-4)`1(BP6"C0``2(T$T$B+4`A(B1!(A=)T
MTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(TMI"T``)`QP$B)WDB)[^BC
M\___2(7`=#9(8U0D!$B+!3*-``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`
M"$B)$$B%TG7PZ[YF#Q]$``!,C25D+0``D#'`2(G>3(GGZ%/S__](A<!T-DAC
M5"0$2(L%XHP``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#K
MOF8/'T0``$R-)<DL``"0,<!(B=Y,B>?H`_/__TB%P'0V2&-4)`1(BP62C```
M2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TU
MT"P``)`QP$B)WDR)]^BS\O__2(7`=#9(8U0D!$B+!4*,``!(C0302(M0"$B)
M$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C2V*+```D#'`2(G>
M3(GOZ&/R__](A<!T-DAC5"0$2(L%\HL``$B-!-!(BU`(2(D02(72=-)FD$B+
M4!!(@\`(2(D02(72=?#KOF8/'T0``$R-/40L``"0,<!(B=Y,B?_H$_+__TB%
MP'0V2&-4)`1(BP6BBP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```3(T]DBL``)`QP$B)WDR)_^C#\?__2(7`=#9(8U0D!$B+
M!5*+``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$
M``!(B=Y(C3VK*P``Z'GQ__](A<!T#4B)QDR)[S'`Z!?U__\QP$B)WDB-/9DK
M``#H5O'__TB%P'012(G&2(T]ERL``#'`Z/#T__](B=Y(C3V1*P``,<#H+_'_
M_TB)QDB%P'0Y3(GG,<#HS?3__TB+1"0(9$@K!"4H````=41(@\082(GO2(TU
M>RL``#'`6UU!7$%=05Y!7^F>]/__,<!(B=Y(C3U-*P``Z-WP__](A<!TNTB)
MQDR)]S'`Z'OT___KK.BD[/__#Q]``$B#[!AD2(L$)2@```!(B40D"(L%&(H`
M`(/X_W0;2(M4)`AD2"L4)2@```!U0DB#Q!C#9@\?1```2(UT)`1(C3V+*@``
M,<#H=?#__TB)PC'`2(72=!(/M@(\,`^5PH3`#Y7`#[;`(=")!<.)``#KKN@L
M[/__9F8N#Q^$``````"02(/L".A7[/__B<?HT.K__TB%P'0#2(L`2(/$",,/
M'P!!54%43(TEDRH``%5(B?U,B>=32(/L&&1(BP0E*````$B)1"0(,<!(C70D
M!.CO[___2(7`=`B`.`!(B<-U,DB+1"0(9$@K!"4H````#X6T````2(GN2(/$
M&$R)YS'`6UU!7$%=Z6?S__\/'X``````2(GN2(G'Z/7J__](A<!T($B+1"0(
M9$@K!"4H````=79(@\086UU!7$%=PP\?1```2(GOZ$CJ__](B=])B<7H/>K_
M_TF-?`4"Z)/I__](@^P(28GHO@$```!32,?"_____TB)QTF)Q4R-#1`I``!(
MC0WV*0``,<#HM.O__UA:2(M$)`AD2"L$)2@```!U"$R)[NE/____Z/7J__\/
M'T0``$%72(T-G"D``$B-%68I``!!5F9(#V[!2(T-.RD``$F)_D%52(T]GB@`
M`$%455-(@>R(@0``9$B+!"4H````2(F$)'B!``!(C05Y*```2(U<)!Q(QT0D
M,`````!(QX0DB`````````!(B=Y(QT0D4`````!F2`]NR$B-!2LI``!F#VS!
M9D@/;M!(C04C*0``#RE$)"!F2`]NP69(#V[82(T-$2D``&8/;,)(C04+*0``
M#Q%$)&AF2`]NPF9(#V[@,<!F#VS##Q%$)'AF2`]NP68/;,0/*40D0.@S[O__
M2(7`=`R`.`!(B<4/A5($``#H/>K__XG'Z+;H__](A<`/A,T#``!,BRA-A>T/
MA,$#``!,B>_HR>C__TB-?``!Z!_H__]%#[9%`$F)QTF)Q$6$P'0^2(TMC"@`
M``\?A```````10^VP$R)_TB)Z;X!````2,?"_____S'`28/%`4F#QP+H*^K_
M_T4/MD4`183`==%,C6PD8$B-/>4G``#K$`\?`$F+?0A)@\4(2(7_=#-(B=XQ
MP.AY[?__2(G%2(7`=.&`.`!TW$B)Q^@T[O__A<!TT$B)[^@8Z?__2(G%2(7`
M=3A,C6PD($F+;0!(A>UT*H!]```/A.@"``!(B>_H`.[__X7`#X7X````28MM
M"$F#Q0A(A>UUV0\?`$B)[^C@Y___3(GG28G%Z-7G__]!C80%!`0``$QC^$R)
M_^@BY___051)B>B^`0```$F)Q4B-!:`G``!,C0VG)@``2,?"_____U!(C0V!
M)P``3(GO,<#H/NG__TR)[[[``0``Z*'I__]?05B#^/]U$NA4Z/__1(L(08/Y
M$0^%H0(``$B-M"20````3(GOZ)?H__^)Q87`='%)BPY(BSTWA@``38GH,<!(
MC17;)P``O@$```#H0>;__T4QY$B+A"1X@0``9$@K!"4H````#X42!0``2('$
MB($``$R)X%M=05Q!74%>05_#9I!(B>])@\4(Z.3G__](B<5(A<`/A,W^___I
M^_[__P\?`(N$)*@````E`/```#T`0```#X5X____1(ND)*P```#H#.C__T$Y
MQ`^%8O___XN$)*@````E_P$``#W``0``#X5+____3(G_Z/3E__](B=Y(C3U#
M)@``28G$,<#HL.O__TB%P`^$-P(``$F+/DB)QNC\\O__28G'2(7`#X0@`@``
M3(G_Z%CF__](B<*#^`-^0$B82(TU/B8``$B)5"0(28U\!_SH6.?__X7`=21(
MBU0D"(/Z!`^$?0,``(U"^TB808`\!R\/A&T#``!F#Q]$``"+!:J$``"#^/\/
MA"$#``"%P`^$T0$``$B--9XE``!(C3TJ)0``,<#HQ.[__TB-'0TF``!,C37T
M)0``Z)'E__]32,?"_____TV)Z%!,C0V^)```O@$```!,B>=(C0V_)0``,<#H
M6.?__UA:ZT0/'T``Z'OF__^#.!%U2.A1Y?__@\4!2(/L"$V)Z%-,C0U_)```
M3(GQO@$```!52,?"_____TR)YU`QP.@4Y___2(/$(+[``0``3(GGZ'/G__^#
M^/]TKDR)[^@VY?__3(GF2(T])"0``#'`Z!7N__],B>?H/?K__^GZ_?__#Q^$
M```````Q[>DQ_?__9@\?A```````2(UL)$#K#68/'X0``````$B#Q0A(BWT`
M2(7_#X2'````,<!(B=[H%>K__TB%P'3@@#@`=-M(B<?HP^7__TF)Q4B%P'3+
MZ?7[__])BPY(BSVL@P``38GH,<!(C140)0``O@$```#HMN/__^EP_?__D$B)
MQ^BH^?__2(N$)'B!``!D2"L$)2@````/A7P"``!(@<2(@0``2(GO6UU!7$%=
M05Y!7^E8Y?__OPT```!,C2T:)```Z+?C__]!N%,```!)B<=)B<3IE_O__V8/
M'T0``$V+/NG8_?__QP7.@@```````&8/'T0``#'V3(G_,<#HC.3__XG#A<`/
MA!G^__^Z`@```$C'QN[___^)Q^B/Y?__3(VT)'`!``"Z!@```(G?3(GVZ"CC
M__^`O"1P`0```'4.@+PD<0$``$,/A&(!```QTC'VB=_H5>7__S'`Z-X;``!(
MB<7K%&8/'X0``````$R)]DB)[^@5'```N@"```!,B?:)W^C6XO__B<*%P'_@
MB=],C;0D(`$``$B-G"1H`0``Z%GB__](B>Y,B?=(C2U0(P``Z'<=``!(C80D
M0`$``$B)1"0(28G'#Q^``````$4/M@9,B?](B>F^`0```$C'PO____\QP$F#
MQP))@\8!Z-OD__],.?MUUDB-!4\C``#&A"1H`0```%#_="002(T-#",``$V)
MZ$R)YS'`O@$```!,C0WW(0``2,?"_____^B;Y/__65[IEOW__P\?0``QP$B)
MWDB-/1,B``#H_^?__TB%P`^$CO[__P^V`(3`#Y7"/#`/E<`/ML`AT(D%3H$`
M`.FH_/__38MV"$V%]@^$C/S__TR)]^B4XO__2(/X`P^&>OS__TF-?`;\2(TU
M>B(``.B9X___A<!-#T3^Z5[\__^`O"1R`0``00^%D/[__X"\)',!``!##X6"
M_O__@+PD=`$``$@/A73^__^`O"1U`0``10^%9O[__[H"````2,?&QO___XG?
MZ+/C__^Z*0```$R)]HG?Z%3A__](C04](@``4$%6Z?/^___H$./__T%455-(
M@^P0BSVB@```9$B+!"4H````2(E$)`@QP$B-;"0$Z#CC__^+/8*```!(B</H
M*N/__P^VD[````!(B>Y(C3W<(```B)"Q````,<#HW.;__TB%P'0)@#@Q#X2N
M`0``,<#HI_'__XL]08```.CLXO__N0,```"Z`0```$B--:HA``!(B<?H\^#_
M_TB)PTB%P'0U2(M`$(L]$8```$R+(.BYXO__2(T5@R$``$B)QTR)YNCWX/__
M2(M#$$B+&/9##D`/A88!``"+/>!_``#HB^+__[D#````N@$```!(C350(0``
M2(G'Z)+@__](B<-(A<!T/4B-/?0?``!(B>XQP.@IYO__BSVC?P``28G$2(7`
M#X0'`0``2(M#$$B+&.@[XO__3(GB2(G'2(G>Z'W@__^+/7=_``#H(N+__[H!
M````2(TU[B```$B)Q^A^W___BSU8?P``2(G#Z`#B__](B=Y(C17C(```2(G'
MZ#[@__^+/3A_``#HX^'__TB)[DB-/6$?``#&@+$`````,<#HF^7__TB)!71_
M``!(B<-(A<!T/+[``0``2(G?Z&_B__^-4`&#^@%V"8/X$0^%J0```$B+1"0(
M9$@K!"4H````#X6R````2(/$$%M=05S#D$B+/3%_``#H-/;__TB)!1U_``!(
MB<-(A<!UJ4B-/?8@```QP.AGX?__#Q^``````(!X`0`/A$_^___I0_[__Y!(
MBP7Q?@``3(L@2(M#$$B+&.@JX?__3(GF2(G?Z+_G___I[?[__V8N#Q^$````
M``"+/5I^``#H!>'__TB)WDB)Q^B:X/__Z5_^__^)P4B+!:1^``!(B=I(C3VB
M(```2(LP,<#HZ.#__^B#X/__#Q\`05152(G]4TB#[!!D2(L$)2@```!(B40D
M"#'`Z"#N__^^+P```$B)QTB)P^B@W___2(7`2(U0`4@/1=I(B=_H'>#__TB%
M[4F)Q(L%P7T```^5PX/X_W1IA<`/E<`APX3;=1Y(BT0D"&1(*P0E*`````^%
MF0```$B#Q!!;74%<PY"`?0``=-RZ!````$B--=`>``!,B>?H)M[__X7`=<1(
MBT0D"&1(*P0E*````'5A2(/$$$B)[UM=05SI0N7__V:0,<!(C70D!$B-/>$=
M``#HS>/__TB%P'0H#[80A-(/E<"`^C`/E<(AT"'##[;`B04=?0``Z6;___\/
M'X0``````,<%!GT```````#I4____^ALW___9BX/'X0``````&:005=(B?Y,
MC4<X059!54%455-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)XDR-C"2`
M````2(G7#Q^``````$&+`$V+$$B#QQ!)@\`(#\B)P$R)T4B)1_!,B=!(P>D@
M2,'H*$G!ZC@E`/\``$P)T$F)RDC!X0A)P>(8@>$``/\`18G23`G02`G(2(E'
M^$PYSW6M9@]O1"009@]O7"0@2(U$)&A(@<)H`@``9@]O5"0P9@]O+0==```/
M'X``````\P]O"&8/;^)F#V]0V$B#P!!F#^]`B&8/[\IF#^_!9@]OR&8/<]`?
M9@]S\0%F#^O!9@_;Q0\I0`AF#V_#9@]OW$@YT'6[3(L.3(M>$$B+?B!(BUX8
M3(G(3(G*2(MN"$B+3"0(2,'J&TC!X`5("=`#!"1(C8P+F7F"6HV4.)EY@EI,
MB=A(,=A((>A(,=B-/`)(B>I(B>A(P>@"2,'B'DF)^D@)PDR)V$G!ZAM!B=!,
M,<!,(<A,,=A(`<A(B?E(P>$%3`G13(M4)!!$C20(3(G(3(G)2,'I`DC!X!Y/
MC903F7F"6DV)Y4@)R$G![1M(,<*)P4@A^DPQPDP!TDV)XDG!X@5-">I,BVPD
M&$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=")UTPAX$G![1M(
M,<A,`<!-B=!)P>`%30GH3(ML)"!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):
M3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD*`'13(G2
M2<'J`DC!XAZ)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!^$B)
MSTC!YP5,">],BVPD,`''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"
M2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q,BVPD.$$!U$B)RDC!Z0)(P>(>
M18GD3XV4*IEY@EI("<I-B>5(,=!)P>T;B=%((?A,,<!,`=!-B>))P>(%30GJ
M3(ML)$!!`<)(B?A(P>\"2,'@'D6)TD^-A"B9>8):2`GX38G52#'"2<'M&XG'
M3"'B2#'*3`'"38G02<'@!4T)Z$R+;"1(00'03(GB2<'L`DC!XAY%B<!*C8PI
MF7F"6DP)XDV)Q4@QT$G![1M!B=1,(=!(,?A(`<A,B<%(P>$%3`GI3(ML)%`!
MP4R)T$G!Z@)(P>`>B<E*C;POF7F"6DP)T$F)S4@QPDG![1M!B<),(<),,>)(
M`?I(B<](P><%3`GO3(ML)%@!UTR)PDG!Z`)(P>(>B?]/C:0LF7F"6DP)PDF)
M_4@QT$G![1M!B=!((<A,,=!,`>!)B?Q)P>0%30GL3(ML)&!!`<1(B<A(P>`>
M2,'I`D6)Y$^-E"J9>8):2`G(38GE2#'"2<'M&XG!2"'Z3#'"3`'238GB2<'B
M!4T)ZDR+;"1H00'22(GZ2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)U4@QT$G!
M[1N)UTPAX$@QR$P!P$V)T$G!X`5-">A,BVPD<$$!P$R)X$G![`)(P>`>18G`
M2HV,*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A!4P)Z4R+
M;"1X`=%,B=)(P>(>2<'J`HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;08G23"'`
M3#'@2`'X2(G/2,'G!4P)[TR+K"2``````<=,B<!)P>@"2,'@'HG_3XVD+)EY
M@EI,"<!)B?U(,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)[$:-+")(B<I(
MP>D"3(ND)(@```!(P>(>2`G*3XV4(IEY@EI-B>Q(,=!)P>P;B=%((?A,,<!,
M`=!-B>I)P>(%30GB3(ND))````!!`<)(B?A(P>`>2,'O`D6)TD^-A""9>8):
M2`GX38G42#'"2<'L&XG'3"'J2#'*3`'"38G02<'@!4T)X$6)P$P!PDV)Z$G!
M[0))P>`>08G430GH3(NL))@```!,,<!,(=!*C8PIF7F"6DV)Y4@Q^$G![1M(
M`<A,B>%(P>$%3`GIB<E(`<A,B=%)P>H"2,'A'D&)Q4P)T4V)PD6)P$DQRD0Q
MTDR+E"2@````2HV\%Z'KV6Y-B>I(`==,B>I)P>H;2,'B!4P)THG22`'73(GB
M2,'B'DG![`)!B?I,`X0DJ````$P)XDF)S(G)2`.,)+````!),=1$,>!-C:0`
MH>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<1,B>A)P>T"2,'@'D6)X$P)Z$F)
MU8G22`.4)+@```!),<5$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)
M`<U,B=%)P>H"2,'A'D2)[TP)T4F)PHG`23'*13'B3HVD$J'KV6Y(B?I)B?I)
MP>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<A(`X0DP````(G)
M23'02`.,),@```!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(
MB?A(P>\"2,'@'D6)Z$@)^$B)UXG22`.4)-````!(,<=$,>=,C:0YH>O9;DR)
MP4R)QTC![QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$
M)-@```!),<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))
MP>@"2,'B'D6)ZDP)PDF)R(G)23'02`.,).````!%,>!.C:0`H>O9;DR)T$V)
MT$G!Z!M(P>`%3`G`B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4).@`
M``!(,<=$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"
M2,'A'D2)[TP)T4F)PHG`2`.$)/````!),<I%,>).C:02H>O9;DB)^DF)^DG!
MZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL
M`*'KV6Y,B=!-B=!(P>`%2<'H&T@#C"3X````3`G`B<!)`<5(B?A(P>\"2,'@
M'D6)Z$@)^$B)UXG22`.4)``!``!(,<=$,>=,C:0YH>O9;DR)P4R)QTC![QM(
MP>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$)`@!``!),<I%
M,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"2,'B'D6)
MZDP)PDF)R(G)23'013'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P$@#C"00
M`0``B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4)!@!``!(,<=$,>],
MC:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)[TP)
MT4F)PHG`2`.$)"`!``!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2
MB=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'KV6Y,B=!-
MB=!)P>@;2,'@!4P)P(G`20'%2(GX2,'@'DC![P)%B>A(`XPD*`$``$@)^$B)
MUXG22`.4)#`!``!(,<=$,>=-B<1(C8PYH>O9;DR)QTG![!M(P><%3`GG38G4
M2<'J`DG!Y!Z)_TT)U$F)PD@!^8G`33'BB<](`X0D.`$``$4QZDF)_4Z-E!*A
MZ]EN2(GZ2<'M&TC!X@5,">I!`=),B<))P>@"2,'B'D6)TDP)PDV)X$6)Y$DQ
MT$F)UD&)U40QP4V)T$B-C`BAZ]EN3(G02<'H&TC!X`5,"<!$C00!2(GY2,'O
M`KC<O!N/2,'A'D@)^4D)SHG/2"'Z32'620G62(N4)$`!``!(`<),`>)-B<1,
M`?)-B<9)P>0%2<'N&TT)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G2
M22'^3"'!3`GQ3(NT)$@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)
MUD$!S4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)%`!``!)
M`<9,`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)
MT4F)UD&)U$TAQDPAZ4P)\4R+M"18`0``20'&30'R28G^3`'128GZ2<'N&TG!
MX@5-"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+
MM"1@`0``20'&30'P38G63`'"38G02<'@!4G![AM-"?!!`=!(B?I(P>\"2,'B
M'D6)P$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)&@!``!)`<9-`?1-B<9,`>%-
MB<1)P>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G108G*20G.32'&
M3"'23`GR3(NT)'`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)
MPDC!XAY)P>@"18GM3`G"2`G128G608G032'63"'A3`GQ3(NT)'@!``!)`<9,
M`?=-B>Y(`?E,B>])P>X;2,'G!4P)]TF)U@'/3(GA2<'L`DC!X1Z)_TP)X4&)
MS$D)SDTA[DPAXDP)\DR+M"2``0``20'&30'R28G^3`'228GZ2<'N&TG!X@5-
M"?)!`=),B>I)P>T"2,'B'D6)TDP)ZD@)T4F)UD&)U4@A^4TAYDP)\4R+M"2(
M`0``20'&30'P38G63`'!38G02<'N&TG!X`5-"?!)B=9!`<A(B?E(P>\"2,'A
M'D6)P$@)^8G/20G.32'62"'Z3`GR3(NT))`!``!)`<9-`?1-B<9,`>)-B<1)
MP>X;2<'D!4T)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G222'^3"'!
M3`GQ3(NT))@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!S4R)
MP4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)*`!``!)`<9,`?=-
MB>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)UD&)
MU$TAQDPAZ4P)\4R+M"2H`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-"?))
MB=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"2P`0``
M20'&30'P38G63`'"38G02<'N&TG!X`5-"?!!`=!(B?I(P>\"2,'B'D6)P$@)
M^D@)T4F)UHG732'N3"'13`GQ3(NT)+@!``!)`<9-`?1-B<9,`>%-B<1)P>X;
M2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G120G.08G*32'&3"'23`GR
M3(NT),`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDG!Z`)(
MP>(>18GM3`G"2`G128G008G732'03"'A3`G!3(N$),@!``!)`<!,`<=-B>A(
M`?E,B>])P>@;2,'G!4P)QT2-!#E,B>=)P>P"2(G12,'G'DP)YT&)_$@)^4PA
MZ4PAXD@)RDB+C"30`0``2`'!3`'138G"2`.$)-@!``!(`<I,B<%)P>H;2,'A
M!4P)T8G)2`'*3(GI2<'M`DC!X1Y!B=),">E("<])B<U!B<Y,(<=-(>5)"?U*
MC3PX3(G03(N\)/@!``!,`>]-B=5(P>`%2<'M&TP)Z(G`2`''3(G`2<'H`DC!
MX!Y!B?U)"<"XUL%BRDPQP3'12(N4).`!``!(`<),`>)-B>Q(`<I,B>E)P>P;
M2,'A!4P)X4V)U(G)2<'D'D@!RDG!Z@))`<=-">)-B<2)T46)P$TQU$0QYTR+
MI"3H`0``20'$30'T28G.3`'G28G,2<'N&TG!Y`5-"?1-B>Y)P>T"2<'F'D6)
MY$T)]4R+M"3P`0``3`'G08G\20'&30'P38G633'N1#'R38GF20'03(GB2<'N
M&TC!X@5,"?*)TDD!T$B)RDC!Z0)(P>(>18G&2`G*1(G138GJ23'23`'Y3(N\
M)``"``!$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L`DC!
MX1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"00`@``13'H38G520'(3(G12<'M
M&TD!QTC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)`@"``!)`<9,
M`?)-B>9),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J`DC!
MXAY!B?Y)"=)$B>))B<R)R4P!^DTQU$R+O"0@`@``13'@38GT20'03(GR2<'L
M&TD!QTC!X@5,">*)TDD!T$R)ZDG![0)(P>(>18G$3`GJ3(NL)!@"``!)`<5,
M`>E-B=5),=5$,>]-B>5(`<],B>%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N`DC!
MX1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"0P`@``13'038GJ20'(3(GI2<'J
M&TC!X05,"=&)R4D!R$R)X4C!X1Y)P>P"18G"20''3`GA3(ND)"@"``!)`<1,
M`>)-B?1),<Q$,>=-B=1(`==,B=))P>P;2,'B!4P)XHG22`'73(GJ2<'M`DC!
MXAY!B?Q)"=5$B?))B<Z)R4TQ[DP!^DR+O"1``@``13'P38GF20'03(GB2<'N
M&TC!X@5,"?*)TDD!T$R)TDG!Z@)(P>(>18G&3`G23(N4)#@"``!)`<),`=%-
MB>I),=)$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L`DC!
MX1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"1@`@``13'H38G520'(3(G12<'M
M&TC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)$@"``!)`<9,`?)-
MB>9%B>1),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J`DC!
MXAY!B?Y)"=)(BY0D4`(``$@!PDD!U$B)RHG)3#'220''1#'"38GP20'43(GR
M2<'H&TC!X@5,"<*)TDD!U$R)ZDG![0)(P>(>18G@3`GJ3(NL)%@"``!)`<5,
M`>E-B=5),=5$,>]-B<5(`<],B<%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N`DC!
MX1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"1P`@``13'B38GL3`'138GJ2<'L
M&TG!X@5-">)-B<1%B=))P>0>3`'12<'H`DD!QTT)X$R+I"1H`@``08G*20'$
M2`.$)'@"``!,`>)-B?1,`<A-,<1$,>=-B=1(`==,B=))P>P;2,'B!4P)XDV)
M[$G![0))P>0>B=)-">5%B?1-B<9(`==-,>Z)^DT!_$6)P$0Q\4F)UDP!P$V)
MZ$P!X4F)U$G![AM)P>0%30GT1`'A38G42<'J`DG!Y!Z)R4T)XDTQT$0QQTF)
MR$@!^$B)STC!YP5)P>@;`>E!`=I,"<=$`VX@2(E."`'X3(E6&$B)!DB)T$C!
MZ@)(P>`>3(EN($@)T$0!V$B)1A!(BX0DB`(``&1(*P0E*````'422('$F`(`
M`%M=05Q!74%>05_#Z/;(__]F#Q]$``!(@^P(OX````#H,L?__V8/;P5*1P``
M2,=`,``````/$0!F#V\%1T<``,=`>``````/$4`09@]O!41'```/$4`@2(/$
M",-F9BX/'X0``````$%72&/"059)B<9!54%428G\54B-;SA32(GS2(/L"$B+
M=RA(BU<PC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC1WB%P`^%[0```$&#
M_C\/CBL!``!!@^Y`18GW0<'O!D6-;P%)P>4&20'=#Q]$``#S#V\#3(GG2(/#
M0`\110#S#V]+T`\131#S#V]3X`\152#S#V];\`\173#HH>C__TPYZW7,0<'G
M!D4I_DECQDB#^`AR7$F+50!(C4T(2(/A^$F)5"0X28M4!?A(B50%^$@IS4@!
MZ$DI[4B#X/A(@_@(<AA(@^#X,=))BW05`$B)-!%(@\((2#G"<NY%B70D>$B#
MQ`A;74%<05U!7D%?PV:0J`1U=$B%P'3A00^V50!!B%0D.*@"=--!#[=4!?YF
MB50%_NO&#Q]``$&_0````$B-?`4`2(G>02G'13GW10]/_DUC[TR)ZN@UR/__
M08M$)'A$`?A!B40D>(/X0'623(GG12G^3`'KZ,7G___IR_[__TF)W>DC____
M08M5`$&)5"0X08M4!?R)5`7\Z5O___^0059,C78X055!5%5(B?U33(MN*$B)
M\TR+9C!,B>A(P>@#@^`_C4@!2)C&1`8X@$ACP4P!\(/Y.`^.@P$``+Y`````
M*<YT#S'2B=&#P@'&!`@`.?)R\TB)W^A#Y___9@_OP`\10SA)QT8P`````$$/
M$48000\11B!,B>)!#[;%3(GO3(GN2,'J&$C!X`A,B>%(P>\028G03(GJ2,'N
M&`^VUD`/MO]`#[;V2,'I$$@)T$R)X@^VR4C!X`A("?@/MOY!#[;02,'@"$@)
M\$$/MO1(P>`(2`GP2,'@"$@)^$B)WTC!X`A("<A(P>`(2`G02(E#<.BJYO__
M2(L#2(G?2,'H&(A%`$B+`TC!Z!"(10%(BP.(90)(BP.(10-(BT,(2,'H&(A%
M!$B+0PA(P>@0B$4%2(M#"(AE!DB+0PB(10=(BT,02,'H&(A%"$B+0Q!(P>@0
MB$4)2(M#$(AE"DB+0Q"(10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&(AE
M#DB+0QB(10](BT,@2,'H&(A%$$B+0R!(P>@0B$412(M#((AE$DB+0R"(11-;
M74%<05U!7NDJQ/__9BX/'X0``````+HX````,?\IRH/Z"')"B=%(QP``````
M2,=$"/@`````2(U("$B#X?A(*<@!PH/B^(/Z"`^"?O[__X/B^#'`B<:#P`A(
MB3PQ.=!R\^EG_O__]L($=2.%T@^$6O[__\8``/;"`@^$3O[__S')9HE,$/[I
M0O[__P\?`,<``````,=$$/P`````Z2S^__\/'T0``$B+#3%B``#IQ,+__TB#
M[`A(@\0(PP``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"4P,G@`)7,E<R5S)7,`
M<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].
M`#$N,#4V`"UE`"TM```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O
M9F9S971?<VEZ92P@)$-!0TA%7VUA<FME<BP@)&-A8VAE7VYA;65?<VEZ92D[
M"D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F
M<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]M87)K97(@/2`B
M7#!#04-(12(["B1C86-H95]N86UE7W-I>F4@/2`T,#L*?0IS=6(@9FEN9%]P
M87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T
M("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@
M/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D
M<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@
M/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C
M:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@
M<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1P;W,@*ST@)&D[
M"G)E='5R;B`D<&]S.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N
M("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-
M;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U
M:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D
M<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T
M;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F
M:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B([
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*
M+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M
M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M
M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R
M9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA
M;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T
M87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O
M9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S
M($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ
M<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!
M4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D
M8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B
M3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I
M<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*
M;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@
M,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@
M)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O
M?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T
M<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA
M;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK
M*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D
M=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D
M;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I
M;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S
M879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF
M;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D
M(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@
M8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I
M<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*=6YL97-S("@D8G5F(&5Q(")0
M2UPP,#-<,#`T(BD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%
M('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*
M?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@
M(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D
M(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T
M85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I
M;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID
M:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E
M<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@
M(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*
M;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?<&]S*2!["G)E860@7T9(
M+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92!["FQO8V%L("0O(#T@=6YD
M968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1L;V%D97(L("0P*3L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@
M>PIM>2`D<&%R7V-L96%N(#T@(CTQ(CL*;7D@)'!A<W-?<&%R7V-L96%N(#T@
M=6,@(E]?<&%S<U]P87)?8VQE86Y?7R(["B1L;V%D97(@/7X@<WLH/SP])'MP
M87-S7W!A<E]C;&5A;GTI*"`K*7T*>R1P87)?8VQE86X@+B`H(B`B('@@*&QE
M;F=T:"@D,2D@+2!L96YG=&@H)'!A<E]C;&5A;BDI*7UE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T
M;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\
M?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@
M("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N
M86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*
M?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^
M(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO
M*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT
M(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ
M<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O
M(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X[
M"F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S
M*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II
M<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T
M(ET["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C
M86-H95]N86UE7W-I>F4["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M
M/FYE=R@Q*3L*;W!E;B!M>2`D=&@L("(\.G)A=R(L("1O=70["B1C='@M/F%D
M9&9I;&4H)'1H*3L*8VQO<V4@)'1H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE
M>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE
M7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`D
M8V%C:&5?;6%R:V5R.PIM>2`D;V9F<V5T(#T@)&9H+3YT96QL("L@;&5N9W1H
M*"1C86-H95]N86UE*2`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92P*<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*0HF
M)B`D9F@M/F-L;W-E"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@
M;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ
M2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q
M<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X
M=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY
M("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE
M3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI
M8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C
M=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F
M:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D
M97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE
M*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I
M="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*
M;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N
M86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T
M7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R
M<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I
M8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q
M=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T
M:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M
M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]
M("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@
M*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]
M"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA
M9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D
M9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@D
M8V%C:&5?;6%R:V5R*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE
M;F=T:"@D8V%C:&5?;6%R:V5R*3L*:68@*"1B=68@97$@)&-A8VAE7VUA<FME
M<BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE
M"BT@;&5N9W1H*"1C86-H95]M87)K97(I"BT@)&-A8VAE7VYA;65?<VEZ92P@
M,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@
M<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E
M("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP
M+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y
M<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L
M("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE
M(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F
M=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M
M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H
M*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC
M:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M
M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D[
M"GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA
M;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES
M>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S
M="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*
M?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N
M86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W
M9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN
M,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE
M(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*
M9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)0
M05)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.
M5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID
M96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````!P97)L>'-I
M+F,`````````_____P````#_____``````$C16<`````B:O-[P````#^W+J8
M`````'94,A``````\.'2PP````````````````$;`SOL````'`````!___\X
M`0``@(+__V`!``"0@O__]`4``)"$__\(`0``@(7__W@!``!0AO__Q`$``."&
M___H`0``4(C__R0"```PB?__8`(``'"+__^L`@``X(O__\0"```0C/__W`(`
M`-",__\(`P``X(S__QP#``#PCO__?`,``""/__^8`P``8)#__]`#``#`E/__
M'`0``$"5__\X!```8)7__U`$``!PEO__K`0``%">__]\!0``X*#__[`%````
MHO__(`8``'"X__]P!@``P+C__X@&``!@NO__U`8``+"\__\8!P```````!0`
M`````````7I2``%X$`$;#`<(D`$'$!0````<````@(/__R(`````````````
M`!0``````````7I2``%X$`$;#`<(D`$``"0````<````P'W__X`#````#A!&
M#AA*#PMW"(``/QH[*C,D(@`````4````1````!B!__\(``````````````!(
M````7`````"$___,`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#
M!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L`(````*@```"$A/__@P``
M``!!#A"#`DH.L`$"<0H.$$$."$$+.````,P```#PA/__;`$```!"#A"-`D(.
M&(P#00X@A@1!#BB#!4<.T`%^"@XH00X@00X80@X00@X(1PL`.`````@!```D
MAO__TP````!"#A"-`D<.&(P#00X@A@1$#BB#!5$.P"`"9PH.*$$.($$.&$(.
M$$(."$0+2````$0!``#(AO__,0(```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&1`XX@P='#E`#%0$*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"Q0```"0`0``
MO(C__VD`````1`X0`F`."!0```"H`0``%(G__S``````1`X05@X(`"@```#`
M`0``+(G__[D`````00X0A@)!#AB#`T<.P$`"H0H.&$0.$$$."$$+$````.P!
M``#`B?__!0````````!<``````(``+R)__\"`@```$(.$(\"0@X8C@-"#B"-
M!$(.*(P%2PXPA@9!#CB#!TH.\"$"9`H..$$.,$$.*$(.($(.&$(.$$(."$0+
M`KD.^"%/#H`B6@[X(4$.\"$````8````8`(``&R+__\B`````$$.$(,"7`X(
M````-````'P"``"`B___,0$```!!#A"&`D$.&(,#1PZP(`+A"@X800X000X(
M1`M:"@X82`X000X(30M(````M`(``(B,__]<!````$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9(#CB#!T0.4`,"!`H..$T.,$$.*$(.($(.&$(.$$(."$4+
M&``````#``"<D/__=`````!$#B!M"@X(1PL``!0````<`P```)'__QT`````
M1`X06`X(`%@````T`P``")'__PL!````0@X0C0)"#AB,`T@.((8$1PXH@P5$
M#D`"0@H.*$8.($$.&$(.$$(."$P+9`H.*$$.($$.&$(.$$(."$8+80Y(20Y0
M8PY(00Y`````S````)`#``"\D?__X`<```!"#A"/`E`.&(X#40X@C01)#BB,
M!4$.,(8&00XX@P='#L"#`@/K`0[(@P)A#M"#`E\.R(,"0@[`@P(";@H..$0.
M,$$.*$(.($(.&$(.$$(."$,+`S`!#LB#`DL.T(,"7@[(@P)!#L"#`EP.R(,"
M1`[0@P)0#MB#`DL.X(,"2P[`@P("Y@H..$0.,$$.*$(.($(.&$(.$$(."$4+
M`U(!#LB#`D0.T(,":`[(@P)!#L"#`@+="@[(@P)"#M"#`D4+`#````!@!```
MS)C__XT"````0@X0C`)!#AB&`T$.((,$1`XP`](!"@X@00X800X00@X(0@M`
M````E`0``"B;__\4`0```$(.$(P"00X8A@-$#B"#!$0.,`)O"@X@00X800X0
M0@X(0@MR"@X@1`X800X00@X(1PL``"@```#8!```E'S___H!````00X0A@)!
M#AB#`T0.4`.3`0H.&$,.$$$."$$+3`````0%``#8F___:A8```!"#A"/`DD.
M&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`T(6"@XX00XP00XH0@X@0@X8
M0@X00@X(00L````4````5`4``/BQ__]%`````$0.$`)`#@A(````;`4``#"R
M__^?`0```$(.$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#!T<.0`+E"@XX
M00XP00XH0@X@0@X80@X00@X(0PL`0````+@%``"$L___2P(```!"#A".`D8.
M&(T#0@X@C`1!#BB&!40.,(,&`YL!"@XH00X@0@X80@X00@X(3PL````````0
M````_`4``)"U__\,````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"0)@```````%`F
M`````````0````````#?`@````````$`````````[P(````````,````````
M```@````````#0````````#<70```````!D`````````X+L````````;````
M``````@`````````&@````````#HNP```````!P`````````"`````````#U
M_O]O`````*`#````````!0````````"`#0````````8`````````F`0`````
M```*`````````'`$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````H!0```````!0`````````
M!P`````````7`````````+`4````````!P`````````P$P````````@`````
M````@`$````````)`````````!@`````````'@`````````(`````````/O_
M_V\``````0``"`````#^__]O`````+`2````````____;P`````!````````
M`/#__V\`````\!$```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#PNP``````````````````````````
M```V(````````$8@````````5B````````!F(````````'8@````````AB``
M``````"6(````````*8@````````MB````````#&(````````-8@````````
MYB````````#V(`````````8A````````%B$````````F(0```````#8A````
M````1B$```````!6(0```````&8A````````=B$```````"&(0```````)8A
M````````IB$```````"V(0```````,8A````````UB$```````#F(0``````
M`/8A````````!B(````````6(@```````"8B````````-B(```````!&(@``
M`````%8B````````9B(```````!V(@```````(8B````````EB(```````"F
M(@```````+8B````````QB(```````#6(@```````.8B````````]B(`````
M```&(P```````!8C````````)B,````````V(P```````$8C````````5B,`
M``````!F(P```````'8C````````AB,```````"6(P``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#88@```````$=#
M0SH@*$1E8FEA;B`Q,BXR+C`M,2D@,3(N,BXP```N<VAS=')T86(`+FEN=&5R
M<``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E
M+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I
M;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N
M<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YD871A
M`"YB<W,`+F-O;6UE;G0`````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M````````&`,````````8`P```````!P````````````````````!````````
M````````````$P````<````"`````````#@#````````.`,````````@````
M````````````````"````````````````````"8````'`````@````````!8
M`P```````%@#````````)`````````````````````0`````````````````
M```Y````!P````(`````````?`,```````!\`P```````"``````````````
M```````$````````````````````1P```/;__V\"`````````*`#````````
MH`,```````#T``````````8`````````"````````````````````%$````+
M`````@````````"8!````````)@$````````Z`@````````'`````0````@`
M````````&`````````!9`````P````(`````````@`T```````"`#0``````
M`'`$```````````````````!````````````````````80```/___V\"````
M`````/`1````````\!$```````"^``````````8``````````@`````````"
M`````````&X```#^__]O`@````````"P$@```````+`2````````@```````
M```'`````0````@```````````````````!]````!`````(`````````,!,`
M```````P$P```````(`!````````!@`````````(`````````!@`````````
MAP````0```!"`````````+`4````````L!0````````H!0````````8````7
M````"``````````8`````````)$````!````!@``````````(``````````@
M````````%P````````````````````0```````````````````",`````0``
M``8`````````("`````````@(````````(`#```````````````````0````
M`````!``````````EP````$````&`````````*`C````````H",````````(
M````````````````````"``````````(`````````*`````!````!@``````
M``"P(P```````+`C````````+#H``````````````````!``````````````
M``````"F`````0````8`````````W%T```````#<70````````D`````````
M```````````$````````````````````K`````$````"``````````!@````
M`````&`````````@00``````````````````$````````````````````+0`
M```!`````@`````````@H0```````""A````````[```````````````````
M``0```````````````````#"`````0````(`````````$*(````````0H@``
M`````$`&```````````````````(````````````````````S`````X````#
M`````````."[````````X*L````````(````````````````````"```````
M```(`````````-@````/`````P````````#HNP```````.BK````````"```
M``````````````````@`````````"`````````#D````!@````,`````````
M\+L```````#PJP`````````"````````!P`````````(`````````!``````
M````FP````$````#`````````/"]````````\*T````````0`@``````````
M````````"``````````(`````````.T````!`````P``````````P```````
M``"P````````(`````````````````````@```````````````````#S````
M"`````,`````````(,`````````@L````````'@````````````````````@
M````````````````````^`````$````P````````````````````(+``````
M```>`````````````````````0`````````!``````````$````#````````
M`````````````````#ZP`````````0$```````````````````$`````````
(````````````
